pub struct SwarmGenerator { /* private fields */ }Expand description
Swarm testing generator
Generates programs using random feature subsets per batch, implementing the swarm testing strategy from Groce et al.
Implementations
Sourceimpl SwarmGenerator
impl SwarmGenerator
Sourcepub fn generate_batch(&mut self, batch_size: usize) -> Vec<GeneratedCode>
pub fn generate_batch(&mut self, batch_size: usize) -> Vec<GeneratedCode>
Generate a batch of programs with random feature subset
Sourcepub fn generate(
&mut self,
total_count: usize,
batch_size: usize,
) -> Vec<GeneratedCode>
pub fn generate( &mut self, total_count: usize, batch_size: usize, ) -> Vec<GeneratedCode>
Generate multiple batches worth of programs
Sourcepub fn stats(&self) -> &SwarmStats
pub fn stats(&self) -> &SwarmStats
Get generation statistics